@@ -12,17 +12,29 @@ __all__ = ['getLinearChain']
 # General settings for the package
 @dataclass
 class Settings:
+  """ Settings to control some properties of the network generation"""
   rateConstantScale = 1.0
+  """ How much the rate cosntants are scaled by. By default rate constants ge values between 0 and 1.0"""
   allowMassViolatingReactions = False
+  """ If set to true, reactions such as A + B -> A are allowed"""
 
   @dataclass
   class ReactionProbabilities:
+         """ Defines the probabilities of generating different reaction mechanisms.
+         Current probabilities are:
+         
+         UniUni = 0.4
+         BiUni = 0.3
+         UniBi = 0.3
+         BiBI  = 0.05
+         """
          UniUni = 0.4
          BiUni = 0.3
          UniBi = 0.3
          BiBI  = 0.05
 
   def restoreDefaultProbabilities ():
+      """Restore the default settings for the reaction mechanism propabilities"""
       Settings.ReactionProbabilities.UniUni = 0.4
       Settings.ReactionProbabilities.BiUni = 0.3
       Settings.ReactionProbabilities.UniBi = 0.3
@@ -41,24 +53,23 @@ def _getMARateLaw (k, s1, s2):
 def getLinearChain (lengthOfChain, rateLawType='MassAction', keqRatio=5):
     """ Return an Antimony string for a linear chain
     
-    Parameters 
-    ----------      
-        arg1 (integer): Length of generated chain, number of reactions
+    Args:     
+        lengthOfChain (integer): Length of generated chain, number of reactions       
+        rateLawType (string): Optional, can be 'MassAction' (default) or 'Michaelis'
+        keqRatio (float): Optional, maximum size of equilibrium constant
          
-        arg2 (rateLawType String): Optional, can be 'MassAction' (default) or 'Michaelis'
-  
-        arg3 (float): Optional, maximum size of equilibrium constant
-         
-    Return
-    ------
-    result: Antimony string
+    Returns:
+        string :
+           Returns an Antimony string representing the network model
     
-    Example
-    -------     
-    >>> s = teUtils.buildNetworks.getLinearChain (6, rateLawType='MassAction')
-    >>> r = te.loada (s)
-    >>> r.simulate (0, 50, 100)
-    >>> r.plot()
+    Examples:  
+
+    .. code-block:: python 
+
+       >>> s = teUtils.buildNetworks.getLinearChain (6, rateLawType='MassAction')
+       >>> r = te.loada (s)
+       >>> r.simulate (0, 50, 100)
+       >>> r.plot()
     """
     # Set up a default
     getRateLaw = _getMARateLaw
@@ -424,41 +435,54 @@ def _getAntimonyScript (floatingIds, boundaryIds, reactionList, isReversible):
     return antStr       
      
 
-def getRandomNetwork (nSpecies, nReactions, isReversible=False):  
+def getRandomNetwork (nSpecies, nReactions, isReversible=False, returnStoichiometryMatrix=False, returnFullStoichiometryMatrix=False):  
     """
     Generate a random network using uniuni, unibi, biuni, and bibi reactions.
     All reactions are governed by mass-action kinetics. User can set the maximum
     number of reactions and species. 
       
-    Parameters 
-    ----------
-         arg1 (nSpecies integer): Maximum number of species
-         
-         arg2 (nreaction integer): Maximum number of reactions
+    Args:
+         nSpecies (integer): Maximum number of species       
+         nreaction (integer): Maximum number of reactions
+         isReversible (boolean): Set True if the reactions should be reversible  
+         returnStoichiometryMatrix (boolean): Set True to make the function return the stoichiometry matrix that
+             only inludes the floating species. If you want the full stoichiometriy matrix that includes the boundary
+             species as well, set the returnFullStoichiometryMatrix to True
+         returnFullStoichiometryMatrix (boolean): Set True if you want the full stoichometry matrix returned. The 
+             full matrix will include any boundary species in the network.
+               
+    Returns:
+        string :
+           Returns an Antimony string representing the network model
+    
+    Examples::
 
-         arg3 (isReversible boolean): Set True if the reactions should be reversible     
-         
-    Return
-    ------
-        result: Antimony network string
+       >>> model = getRandomNetwork (6, 9)
+       >>> r = te.loada(model)
+       >>> m = r.simulate (0, 10, 100)   
+       
+       >>> model = getRandomNetwork (6, 7, returnStoichiometryMatrix=True)
 
-    Example
-    -------
-    >>> model = getRandomNetwork (6, 9)
-    >>> r = te.loada(model)
-    >>> m = r.simulate (0, 10, 100)      
+         array([[ 0.,  0.,  1.,  0., -1.,  0.,  0.],
+               [ 1.,  0.,  0.,  1.,  0., -1.,  1.],
+               [-1.,  1.,  0.,  0.,  0.,  0.,  0.],
+               [ 0.,  0.,  1.,  0.,  0.,  0., -1.],
+               [ 0., -1.,  0., -1.,  0.,  1.,  0.],
+               [ 0.,  0., -1.,  0.,  1.,  0.,  0.]])
     """ 
     roadrunner.Logger_disableConsoleLogging()
     roadrunner.Config_setValue (roadrunner.Config.ROADRUNNER_DISABLE_WARNINGS, True)
 
     rl = _generateReactionList (nSpecies, nReactions)  
-    #print (rl)
     st = _getFullStoichiometryMatrix (rl)
-    #print (st)
-    #fullNetwork = [st, _np.arange (nSpecies), []]
-    #return _getAntimonyScript (fullNetwork[1], fullNetwork[2], rl, isReversible)
+    
+    if returnFullStoichiometryMatrix:
+       return st
     
     stt = _removeBoundaryNodes (st)
+    if returnStoichiometryMatrix:
+       return stt[0]
+   
     if len (stt[1]) > 0:
        return _getAntimonyScript (stt[1], stt[2], rl, isReversible)
     else:
