@@ -16,7 +16,11 @@ def getODEsFromSBMLFile (fileName):
     """ Given a SBML file name, this function returns the model
     as a string of rules and ODEs
     
-    >>> print (te.getODEsFromSBMLFile ('mymodel.xml'))
+    Args:
+      fileName (string): The path and name of the SBML file
+
+    Example:
+      >>> print (te.getODEsFromSBMLFile ('mymodel.xml'))
     """
 
     sbmlStr = _te.readFromFile (fileName)
@@ -27,7 +31,11 @@ def getODEsFromSBMLString (sbmlStr):
     """ Given a SBML string this fucntion returns the model
     as a string of rules and ODEs
     
-    >>> print (te.getODEsFromSBMLString (sbmlStr))
+    Args:
+      sbmlStr (string): A string representing an SBML model
+
+    Example:
+       >>> print (te.getODEsFromSBMLString (sbmlStr))
     """
 
     extractor = _ODEExtractor (sbmlStr)
@@ -37,8 +45,12 @@ def getODEsFromModel (sbmlModel):
     """Given a roadrunner instance this function returns
     a string of rules and ODEs
     
-    >>> r = te.loada ('S1 -> S2; k1*S1; k1=1')
-    >>> print (te.getODEsFromModel (r))
+    Args: 
+      sbmlModel (string): A reodarunner instance
+      
+    Example:
+      >>> r = te.loada ('S1 -> S2; k1*S1; k1=1')
+      >>> print (te.getODEsFromModel (r))
     """
 
     from roadrunner import RoadRunner
@@ -153,9 +165,9 @@ class _ODEExtractor:
         r = ''
         for i in range (self.model.getNumRules()):
             if self.model.getRule(i).getType() == 0:
-                r += 'd' + self.model.getRule(i).id + '/dt = ' + self.model.getRule(i).formula + '\n'
+                r += 'd' + self.model.getRule(i).getId() + '/dt = ' + self.model.getRule(i).getFormula() + '\n'
             if self.model.getRule(i).getType() == 1:
-                r += self.model.getRule(i).id + ' = ' + self.model.getRule(i).formula + '\n'
+                r += self.model.getRule(i).getId() + ' = ' + self.model.getRule(i).getFormula() + '\n'
         return r
 
     def _getKineticLaws (self):
@@ -179,7 +191,7 @@ class _ODEExtractor:
         r = self._getRules()
         r = r + self._getKineticLaws() + '\n'
         for index in range (self.model.getNumSpecies()):
-            if not self.model.getSpecies (index).boundary_condition:
+            if not self.model.getSpecies (index).getBoundaryCondition():
                r = r + self._getRateOfChange (index)
         return r
 
